// Sparta-Mod XP functions

// Give the player XPs
public GivePlayerXP( id, XPs )
{
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
		
	// Check if there enough players
	MinPlayers();
	
	// The user isn't allowed to get XPs ( to low players on the server )
	if ( !g_AllowGivTakeXP )
	{
		return false;
	}
	
	// The player get the xp
	else
	{
		g_AllowGivTakeXP = false;
	}
	
	// The player is on the last level, give him nothing
	if ( CheckLastLevel( id ) )
	{
		return false;
	}
	
	// the round is over
	if ( g_RoundOver )
	{
		// We don't give the player xps 
		if ( !g_GiveEndRoundXP )
		{
			return false;
		}
		
		// We give the player xps although the round is over, only one time
		else
		{
			g_GiveEndRoundXP = false;
		}
	}
		
	// Add the XPs to the Array
	Player_XPs[id] += XPs;
	
	// Check if the player gained a level
	CheckLevelUp( id );
	
	// Update the StatusBar
	PlayerShowBar( id );
	
	return true;
}

// Take the player XPs
public TakePlayerXP( id, XPs )
{
	if ( !is_user_connected( id ) )
	{
		return false;
	}
	
	// The server, not the admin, will take xp, so we should check if the player is on the last level
	if ( !g_AllowGivTakeXP )
	{
		if ( CheckLastLevel( id ) )
		{
			return false;
		}
	}
	
	// Check if there enough players
	MinPlayers();
	
	// We can't take the XPs ( to low players on the server )
	if ( !g_AllowGivTakeXP )
	{
		return false;
	}
	
	// The player lost the xps
	else
	{
		g_AllowGivTakeXP = false;
	}
	
	// the round is over
	if ( g_RoundOver )
	{
		return false;
	}
	
	// Take the XPs from the Array
	Player_XPs[id] -= XPs;
	
	// We can't go in negative experience
	if ( Player_XPs[id] < 0 )
	{
		Player_XPs[id] = 0;
		
		Player_Level[id] = 1;
		
		// We should check if he lose the ultimate
		CheckLoseUltimate( id );
		
		// We have to reset all skills because the player lost one or more skillpoints
		ResetAllSkills( id );
			
		// Set the abilities from the user 
		Set_User_Abilities( id );
		
		// Set him the new weapon model
		set_task ( 0.2, "task_stripngive", TASK_STRIP + id );
			
		// Send him a message
		client_print ( id, print_chat, "%s You lost a level", SPARTA_NAME );
		
		// We shouldn't write a message
		return false;
	}
	
	// We should check if we lose a level
	else 
	{
		// Save the old level
		static OldLevel;
		OldLevel = Player_Level[id];
		
		// Get the new level
		GetPlayerLevel( id );
		
		// we lost a level ;(
		if ( OldLevel > Player_Level[id] )
		{
			// We should check if he lose the ultimate
			CheckLoseUltimate( id );
			
			// We have to reset all skills because the player lost one or more skillpoints
			ResetAllSkills( id );
			
			// Set the abilities from the user 
			Set_User_Abilities( id );
		
			// Set him the new weapon model
			set_task ( 0.2, "task_stripngive", TASK_STRIP + id );
			
			// Send him a message
			client_print ( id, print_chat, "%s You lost a level", SPARTA_NAME );
			
			// We shouldn't write a message
			return false;
		}
	}
	
	// Update the StatusBar
	PlayerShowBar( id );
			
	return true;
}

// Give Team XPs
public GiveTeamXP( whichteam )
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	static players[32], num, i, id, XPs, TempResult;
	
	// Terrorist won the round so get the xps for terrorist
	if ( whichteam == TEAM_T )
	{
		XPs = get_pcvar_num( sp_twin );
	}
	
	// CounterTerrorist won the round so get the xps for counterterroist
	else
	{
		XPs = get_pcvar_num( sp_ctwin );
	}
	
	// Get the players
	get_players ( players, num );
	
	for ( i = 0; i < num; ++i )
	{
		// save the current id
		id = players[i];
		
		// is the player in the winner team?
		if ( get_user_team( id ) == whichteam )
		{
			// Add the xps to the Array
			TempResult = GivePlayerXP( id, XPs );
			
			// To less players, we shouldn't give xp's
			if ( !TempResult )
			{
				return PLUGIN_CONTINUE;
			}
			
			// Write a message
			client_print ( id, print_chat, "%s You recieved %d XP for winning the round", SPARTA_NAME, XPs );
		}
	}
	return PLUGIN_CONTINUE;
}
			
// Check if the player gained a level
public CheckLevelUp( id )
{
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Save the last level
	static Old_Level;
	Old_Level = Player_Level[id];
	
	// Get the level or the new Level if he gained a level
	GetPlayerLevel( id );
	
	// Check if he gained a level
	if ( Old_Level < Player_Level[id] )
	{
		// Send him a message
		doTypesay ( "You gained a Level!", 10, 210, 0, 0, 1, 20.0, id);
		
		// The player get one skillpoint for every new level
		Player_SkillData[id][AVAILABLE_SKILLS] += ( Player_Level[id] - Old_Level );
		
		// Say that to him
		client_print ( id, print_chat, "%s You recieved %d skillpoint(s) for gaining a level", SPARTA_NAME, ( Player_Level[id] - Old_Level ) );
		
		// Sound a message from wc3ft
		emit_sound ( id, CHAN_STATIC, g_Sound[LEVELUP_SOUND], 1.0, ATTN_NORM, 0, PITCH_NORM );
		
		// Set the abilities from the user 
		Set_User_Abilities( id );
		
		// Set him the new weapon model
		set_task ( 0.2, "task_stripngive", TASK_STRIP + id );
	}
	
	return PLUGIN_CONTINUE;
}

// Check if there enough players
public MinPlayers()
{
	// Check with bots
	if ( get_pcvar_num( sp_botallow ) )
	{
		if ( get_playersnum( 1 ) >= get_pcvar_num( sp_minplayers ) )
		{
			g_AllowGivTakeXP = true;
		}
	}
	
	// Check without bots
	else
	{
		static players[32], num;
		get_players ( players, num, "c" );
		
		if ( num >= get_pcvar_num( sp_minplayers ) )
		{
			g_AllowGivTakeXP = true;
		}
	}
}

// Check if the player on the last level
bool:CheckLastLevel( id )
{
	// The player is on the last level
	if ( Player_Level[id] == MAX_LEVEL )
	{
		return true;
	}
	
	// The player isn't on the last level
	else
	{
		return false;
	}
	
	return false;
}

// Load the XPTables - look in the defs.inl
public XP_TABLES()
{
	static i;
	for ( i = 1; i < ( MAX_LEVEL + 1 ); ++i )
	{
		// The first level need 0 XP!
		if ( i == 1 )
		{
			g_XPforLevel[1] = 0;
			
		}
		
		else if ( i <= 10 )
		{
			g_XPforLevel[i] = g_XPforLevel[i-1] + floatround( XP_FOR_LEVEL * 0.5 );
		}
		
		else if ( i <= 20 )
		{
			// We multiplie the old xp's
			g_XPforLevel[i] = g_XPforLevel[i-1] + floatround( XP_FOR_LEVEL * 0.8 );
		}
		
		else if ( i <= 30 )
		{
			g_XPforLevel[i] = g_XPforLevel[i-1] + floatround( XP_FOR_LEVEL * 1.0 );
		}
		
		else if ( i <= 40 )
		{
			g_XPforLevel[i] = g_XPforLevel[i-1] + floatround( XP_FOR_LEVEL * 1.2 );
		}
		
		else if ( i <= 50 )
		{
			g_XPforLevel[i] = g_XPforLevel[i-1] + floatround( XP_FOR_LEVEL * 1.4 );
		}
	}
}
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
