// Admin functions

public ADMIN_GiveXP( id )
{
	// Sparta-Mod enabled?
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		client_print ( id, print_console, "Sparta-Mod is disabled." );
		
		return PLUGIN_HANDLED;
	}
	
	// Check if the Admin Commands are enabled
	else if ( !get_pcvar_num( g_EnableAdminC ) )
	{
		client_print ( id, print_console, "Admin Commands are disbaled." );
		
		return PLUGIN_HANDLED;
	}
	
	static s_AdminFlag[5];	// For the flag pcvar
	static bit_flags;		// Converted flags
	
	// Get the flags and convert it
	get_pcvar_string ( g_AdminFlag, s_AdminFlag, charsmax( s_AdminFlag ) );
	bit_flags = read_flags ( s_AdminFlag );
	
	if ( !( get_user_flags ( id ) & bit_flags ) )
	{
		client_print ( id, print_console, "You have no Access for that command!" );
		
		return PLUGIN_HANDLED;
	}
	
	// Get the parameters
	new szData1[32], szData2[32];
	read_argv ( 1, szData1, charsmax( szData1 ) );
	read_argv ( 2, szData2, charsmax( szData2 ) );
	
	// Check the format
	if ( read_argc() < 3 )
	{
		client_print ( id, print_console, "Format: sp_givexp (name or steamid) xps" );
		
		return PLUGIN_HANDLED;
	}
	
	// Find a player
	new g_PlayerID = FindPlayer ( szData1 );
	if ( g_PlayerID < 0 )
	{
		client_print ( id, print_console, "Can't find the player '%s'", szData1 );
		
		return PLUGIN_HANDLED;
	}
	
	if ( !is_user_connected ( g_PlayerID ) )
	{
		client_print ( id, print_console, "Error while giving the player XP" );
		
		return PLUGIN_HANDLED;
	}
	
	// Convert the XPs
	new g_NewXPs = str_to_num ( szData2 );
	
	// Set the XP although there aren't enough players
	g_AllowGivTakeXP = true;
			
	// Set the XP
	GivePlayerXP( g_PlayerID, g_NewXPs );
			
	// Give some infos about the admin and the player
	new Player_Get_XP[32], Admin_Set_XP[32];
	get_user_name ( id, Admin_Set_XP, charsmax( Admin_Set_XP ) );
	get_user_name ( g_PlayerID, Player_Get_XP, charsmax( Player_Get_XP ) );
	
	// Send some messages to the admin and the player
	if ( id == g_PlayerID )
	{
		// The Admin gave himself xps
		client_print ( id, print_chat, "%s You gave yourself %d XP", SPARTA_NAME, g_NewXPs );
	}
	
	// Admin gave a player xp
	else
	{
		client_print ( id, print_chat, "%s You gave the Player %s %d XP", SPARTA_NAME, Player_Get_XP, g_NewXPs );
		client_print ( g_PlayerID, print_chat, "%s The admin %s gave you %d XP", SPARTA_NAME, Admin_Set_XP, g_NewXPs );
	}
	
	return PLUGIN_HANDLED;
}

public ADMIN_TakeXP( id )
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		client_print ( id, print_console, "Sparta-Mod is disabled." );
		
		return PLUGIN_HANDLED;
	}
	
	// Check if the Admin Commands are enabled
	else if ( !get_pcvar_num( g_EnableAdminC ) )
	{
		client_print ( id, print_console, "Admin Commands are disbaled." );
		
		return PLUGIN_HANDLED;
	}
	
	static s_AdminFlag[5];		// For the flag pcvar
	static bit_flags;		// Converted flags
	
	// Get the flags and convert it
	get_pcvar_string ( g_AdminFlag, s_AdminFlag, charsmax( s_AdminFlag ) );
	bit_flags = read_flags ( s_AdminFlag );
	
	if ( !( get_user_flags ( id ) & bit_flags ) )
	{
		client_print ( id, print_console, "You have no Access for that command!" );
		
		return PLUGIN_HANDLED;
	}
	
	// Get the parameters
	new szData1[32], szData2[32];
	read_argv ( 1, szData1, charsmax( szData1 ) );
	read_argv ( 2, szData2, charsmax( szData2 ) );
	
	// Check the format
	if ( read_argc() < 3 )
	{
		client_print ( id, print_console, "Format: sp_takexp (name or steamid) xps" );
		
		return PLUGIN_HANDLED;
	}
	
	// Find a player
	new g_PlayerID = FindPlayer ( szData1 );
	if ( g_PlayerID < 0 )
	{
		client_print ( id, print_console, "Can't find the player '%s'", szData1 );
		
		return PLUGIN_HANDLED;
	}
	
	if ( !is_user_connected ( g_PlayerID ) )
	{
		client_print ( id, print_console, "Error while taking the player XP" );
		
		return PLUGIN_HANDLED;
	}
	
	// Convert the XPs
	new g_takeXPs = str_to_num ( szData2 );
	
	// Set the XP although there aren't enough players
	g_AllowGivTakeXP = true;
			
	// Set the XP
	TakePlayerXP( g_PlayerID, g_takeXPs );
			
	// Give some infos about the admin and the player
	new Player_Took_XP[32], Admin_Set_XP[32];
	get_user_name ( id, Admin_Set_XP, charsmax( Admin_Set_XP ) );
	get_user_name ( g_PlayerID, Player_Took_XP, charsmax( Player_Took_XP ) );
	
	// Send some messages to the admin and the player
	if ( id == g_PlayerID )
	{
		// The Admin gave himself xps
		client_print ( id, print_chat, "%s You took yourself %d XP", SPARTA_NAME, g_takeXPs );
	}
	
	// Admin gave a player xp
	else
	{
		client_print ( id, print_chat, "%s You took from the Player %s %d XP", SPARTA_NAME, Player_Took_XP, g_takeXPs );
		client_print ( g_PlayerID, print_chat, "%s The admin %s took %d XP from you", SPARTA_NAME, Admin_Set_XP, g_takeXPs );
	}
	
	return PLUGIN_HANDLED;
}
	
	
// Search a Player
FindPlayer( Args[] )
{
	static iPlayer;	// Save the ID
	
	// Search the player by the full name
	iPlayer = find_player ( "a", Args );
	
	// Not found with full name. Check with a part of the name
	if ( !iPlayer )
	{
		iPlayer = find_player ( "bl", Args );
		
		if ( iPlayer )
		{
			// Is it more than one?
			if ( iPlayer != find_player ( "blj", Args ) )
			{
				return -2;
			}
		}
	}
	
	// Not found with full name and part of the name. Search with the auth id
	if ( !iPlayer )
	{
		iPlayer = find_player ( "c", Args );
	}
	
	// We found nothing :(
	if ( !iPlayer )
	{
		return -2;
	}
	
	return iPlayer;
}
	
	
	
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
