// Sparta-Mod DB Include

// Defines the Tables of the Sparta DB
#define MAX_TABLES 2


new const g_NeedTables[MAX_TABLES][] =
{
	"CREATE TABLE IF NOT EXISTS `sparta_info` ( `player_id` int(8) unsigned NOT NULL auto_increment, `player_steamid` varchar(25) NOT NULL default '', `player_ip` varchar(20) NOT NULL default '', `player_name` varchar(35) NOT NULL default '', `player_xp` int(8) default NULL, `player_ultimate` int(4) default NULL, PRIMARY KEY  (`player_id`), KEY `player_steamid` (`player_steamid`), KEY `player_name` (`player_name`), KEY `player_ip` (`player_ip`) ) TYPE=MyISAM;",
	"CREATE TABLE IF NOT EXISTS `sparta_skills` ( `player_id` int(8) unsigned NOT NULL default '0', `skill_id` int(8) unsigned NOT NULL default '0', `skill_level` int(8) unsigned NOT NULL default '0', PRIMARY KEY  (`player_id`,`skill_id`) ) TYPE=MyISAM;"
}



// Load the Mysql connection and check if there an error
public MYSQL_Init()
{
	// Set the right Affinity
	SQL_SetAffinity ( "mysql" );
	
	// Vars for the DB
	new g_Host[64], g_User[32], g_Pass[32], g_Name[128], g_Errorcode, g_Error[256];
	
	// Get the DB infos
	get_pcvar_string ( db_serverip, g_Host, charsmax( g_Host ) );
	get_pcvar_string ( db_user, g_User, charsmax( g_User ) );
	get_pcvar_string ( db_pass, g_Pass, charsmax( g_Pass ) );
	get_pcvar_string ( db_name, g_Name, charsmax( g_Name ) );
	
	// Open the Tuple
	db_Tuple = SQL_MakeDbTuple ( g_Host, g_User, g_Pass, g_Name );
	
	// Connect to the DB
	db_Connection = SQL_Connect ( db_Tuple, g_Errorcode, g_Error, charsmax( g_Error ) );
	
	// Check if the DB ready
	if ( !db_Connection ) 
	{
		log_amx ( "Database Connection Failed: [%d] %s", g_Errorcode, g_Error);
		
		return false;
	}
	
	// Create the tables
	MYSQL_CreateTables();
	
	// All is okay
	return true;
}

// Create all the tables that we need
MYSQL_CreateTables()
{
	new Handle:query;

	// Create the default tables if we need to
	for ( new i = 0; i < MAX_TABLES; i++ )
	{
		query = SQL_PrepareQuery( db_Connection, g_NeedTables[i] );

		// Check if the DB ready
		if ( !SQL_Execute( query ) )
		{
			MYSQL_Error ( query, g_NeedTables[i] );
	
			return;
		}

		SQL_FreeHandle( query );
	}
}

// Get the UniqueID from the player or create one if it not exists
GetPlayerID( id )
{
	// Checks how to save the xps
	new g_Saveby[128], g_SavebyType[128]; 
	Check_SL ( g_Saveby, charsmax( g_Saveby ), g_SavebyType, charsmax( g_SavebyType ),  id );
	
	// Select the right Player
	new g_Query[512];
	format( g_Query, charsmax( g_Query ), "SELECT `player_id` FROM `sparta_info` WHERE `%s` = '%s';", g_SavebyType, g_Saveby );
	new Handle:query = SQL_PrepareQuery( db_Connection, g_Query );

	// Check if the DB ready
	if ( !SQL_Execute( query ) )
	{
		MYSQL_Error ( query, g_Query );

		return -1;
	}
	
	// We need a var where we save the UniqueID
	new UniqueID = 0;
	
	// If no rows we need to insert!
	if ( SQL_NumResults( query ) == 0 )
	{
		// close the old query
		SQL_FreeHandle( query );
		
		// Insert this player!
		format( g_Query, charsmax( g_Query ), "INSERT INTO `sparta_info` ( `player_id`, `%s` ) VALUES ( NULL, '%s' );", g_SavebyType, g_Saveby );
		query = SQL_PrepareQuery( db_Connection, g_Query );

		// Check if the DB ready
		if ( !SQL_Execute( query ) )
		{
			MYSQL_Error ( query, g_Query );

			return -1;
		}

		// Insert query
		UniqueID = SQL_GetInsertId ( query );
	}
	
	// there are rows!
	else
	{
		UniqueID = SQL_ReadResult( query, 0 );
	}
	
	// Free the handle!
	SQL_FreeHandle( query );
	
	// Return the ID
	return UniqueID;
}

// Save Player XPs
public SavePlayerXP( id )
{
	// We should save in the nvault file
	if ( get_pcvar_num( sp_typesave ) == 1 )
	{
		NVAULT_SaveXP( id );
		return;
	}
	
	// Is the database ready?
	if ( !CheckConnection() )
	{
		return;
	}
	
	// Get the id from the player
	static Player_UniqueID;
	Player_UniqueID = GetPlayerID( id );
	
	// Check if we have a valid ID
	if ( Player_UniqueID <= 0 )
	{
		client_print( id, print_chat, "%s Error, unable to save your XP, please contact a server administrator", SPARTA_NAME );
		
		log_amx ( "Invalid UniqueID! ERROR" );
		return;
	}
		
	// Save the user's XP
	new g_Query[512];
	format( g_Query, charsmax( g_Query ), "UPDATE `sparta_info` SET `player_xp`='%d', `player_ultimate`='%d' WHERE `player_id`='%d';", Player_XPs[id], Player_Ultimate[id], Player_UniqueID );
	new Handle:query = SQL_PrepareQuery( db_Connection, g_Query );

	// Check if the DB ready
	if ( !SQL_Execute( query ) )
	{
		client_print( id, print_chat, "%s Error, unable to save your XP, please contact a server administrator", SPARTA_NAME );

		MYSQL_Error( query, g_Query );

		return;
	}
		
	// Close the Query
	SQL_FreeHandle ( query );
	
	// We have to save the skills
	static i;
	for ( i = 0; i < MAX_SKILLS; ++i )
	{
		if ( Player_Skill[id][i] != 0 )
		{
			format( g_Query, charsmax( g_Query ), "REPLACE INTO `sparta_skills` ( `player_id` , `skill_id` , `skill_level` ) VALUES ( '%d', '%d', '%d' );", Player_UniqueID, i, Player_Skill[id][i] ); 
			query = SQL_PrepareQuery( db_Connection, g_Query );
			
			// Check if the DB ready
			if ( !SQL_Execute( query ) )
			{
				client_print( id, print_chat, "%s Error, unable to save your XP, please contact a server administrator", SPARTA_NAME );
	
				MYSQL_Error( query, g_Query );

				return;
			}
			
			SQL_FreeHandle( query );
		}
	}
	
	// The xps are saved
	client_print ( id, print_chat, "%s Your data is saved now", SPARTA_NAME );
}

// Get the XP from the Player
public GetPlayerXP( id )
{
	id -= TASK_CONNECT_XP;
	
	// We should get the xps & ultimate from the nvault file
	if ( get_pcvar_num( sp_typesave) == 1 )
	{
		// The connection isn't ready, we try it again
		if ( nvault_handle == INVALID_HANDLE )
		{
			set_task ( 1.0, "GetPlayerXP", ( id + TASK_CONNECT_XP ) );
			
			return PLUGIN_CONTINUE;
		}
		
		NVAULT_GetXP( id );
		return PLUGIN_CONTINUE;
	}
	
	// Is the database ready?
	if ( !CheckConnection() )
	{
		set_task( 1.0, "GetPlayerXP", ( id + TASK_CONNECT_XP ) );
		return PLUGIN_CONTINUE;
	}
	
	// Get the id from the player
	static Player_UniqueID;
	Player_UniqueID = GetPlayerID( id ); 
	
	// Check if we have a valid ID
	if ( Player_UniqueID <= 0 )
	{
		client_print( id, print_chat, "%s Error, unable to load your XP, please contact a server administrator", SPARTA_NAME );
		
		log_amx ( "Invalid UniqueID! ERROR" );
		return PLUGIN_CONTINUE;
	}
	
	// Select the right Table
	new g_Query[512];
	format( g_Query, charsmax( g_Query ), "SELECT `player_xp`, `player_ultimate` FROM `sparta_info` WHERE ( `player_id` = '%d' );", Player_UniqueID );
	new Handle:query = SQL_PrepareQuery( db_Connection, g_Query );

	// Check if the DB ready
	if ( !SQL_Execute( query ) )
	{
		MYSQL_Error ( query, g_Query );

		return PLUGIN_CONTINUE;
	}
	
	// Set XPs to zero
	Player_XPs[id] = 0;
	
	// Set ultimate to zero
	Player_Ultimate[id] = 0;
	
	// Set level to zero
	Player_Level[id] = 0;
	
	// Get the XPs and the Ultimate
	Player_XPs[id] = SQL_ReadResult( query, 0 );
	Player_Ultimate[id] = SQL_ReadResult( query, 1 );
		
	// Close the query
	SQL_FreeHandle ( query );
	
	// Get the level from the player
	GetPlayerLevel( id );
	
	// Check if the ultimate from the player is wrong
	CheckLoseUltimate( id );
	
	// Select the right Table
	format( g_Query, charsmax( g_Query ), "SELECT `skill_id`, `skill_level` FROM `sparta_skills` WHERE ( `player_id` = '%d' );", Player_UniqueID );
	query = SQL_PrepareQuery( db_Connection, g_Query );

	// Check if the DB ready
	if ( !SQL_Execute( query ) )
	{
		MYSQL_Error ( query, g_Query );

		return PLUGIN_CONTINUE;
	}
	
	// Delete the old data
	static i;
	for ( i = 0; i < MAX_SKILLS; ++i )
	{
		Player_Skill[id][i] = 0;
	}
	
	// While we have a result!
	new iSkillID = 0;
	while ( SQL_MoreResults( query ) )
	{
		iSkillID = SQL_ReadResult( query, 0 );
		Player_Skill[id][iSkillID] = SQL_ReadResult( query, 1 );

		SQL_NextRow( query );
	}
	
	// Close the connection
	SQL_FreeHandle( query );
	
	// The player get on the server, maybe he forgot to skill now we calculate this!
	CheckAvailableSkills( id );
	
	return PLUGIN_CONTINUE;
}
	
// Close the Mysql connection
public MYSQL_Close()
{
	if ( db_Tuple )
	{
		SQL_FreeHandle ( db_Tuple );
	}
	
	if ( db_Connection )
	{
		SQL_FreeHandle ( db_Connection );
	}
}

// Close the connection and say us what kind of error is it. 
MYSQL_Error( Handle:query, szQuery[] )
{
	new szError[256];
	new iErrNum = SQL_QueryError( query, szError, 255 );

	log_amx ( "Error in querying database" );
	log_amx ( "Message: %s (%d)", szError, iErrNum );
	log_amx ( "Query statement: %s ", szQuery );

	// Free the handle
	SQL_FreeHandle( query );

	// MySQL server has gone away (2006)
	if ( iErrNum == 2006 )
	{
		log_amx( "Attempting to re-establish connection to MySQL server." );
		
		// Close the connection
		MYSQL_Close();

		// Re-open the connection
		MYSQL_Init();
	}
}

public Check_SL( g_Saveby[], s_len1, g_SavebyType[], s_len2, id )
{
	switch ( get_pcvar_num ( sp_saveby ) )
	{
		// It's by SteamID
		case XP_SAVEBY_ID:
		{
			get_user_authid ( id, g_Saveby, s_len1 );
			copy ( g_SavebyType, s_len2, "player_steamid" );
		}
		
		// It's by IP
		case XP_SAVEBY_IP:
		{
			get_user_ip ( id, g_Saveby, s_len1, 1 );
			copy ( g_SavebyType, s_len2, "player_ip" );
		}
		
		// It's by Name
		case XP_SAVEBY_NAME:
		{
			get_user_name ( id,  g_Saveby, s_len1 );
			replace_all( g_Saveby, s_len1, "'", "\'" );
			replace_all( g_Saveby, s_len1, "#", "\'" );
			copy ( g_SavebyType, s_len2, "player_name" );
		}
	}
}

public Start_Connection()
{
	switch ( get_pcvar_num( sp_typesave ) )
	{
		case 0: // Mysql
		{
			MYSQL_Init();
		}
		
		case 1: // Nvault
		{
			NVAULT_Init();
		}
	}
}

bool:CheckConnection()
{
	if ( !db_Tuple || !db_Connection )
	{
		log_amx ( "ERROR! Lost connection to the database server!" );
		
		// Close all connections
		MYSQL_Close();
		
		// Retry the connection
		MYSQL_Init();
		
		return false;
	}
	
	return true;
}
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
