// Sparta-Mod Skills functions

public ChooseSkill( id, side )
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	static MenuText[256];
	formatex ( MenuText, charsmax( MenuText ), "\ySkills Menu\w^n^n" );
	
	// We have to save the side for checking keys later
	Player_SkillData[id][SKILL_SIDE] = side;
	
	static i, KEY; KEY = 0;
	for ( i = side; i < MAX_SKILLS; ++i )
	{
		// Available skills
		if ( Player_Level[id] >= Skill_REQLevel[i] && Player_Skill[id][i] != Skill_Max_Point[i] )
		{
			// Add every skill to the menu
			formatex ( MenuText, charsmax( MenuText ), "%s\w%d. %s [%d/%d] (lvl %d)^n", MenuText, i+1, Skill_Names[i], Player_Skill[id][i], Skill_Max_Point[i], Skill_REQLevel[i] );
			
			// we count it for the valid keys
			KEY |= (1<<i);
		}
	
		// Nonavailable skills
		else 
		{
			// Add every skill to the menu
			formatex ( MenuText, charsmax( MenuText ), "%s\d%d. %s [%d/%d] (lvl %d)^n", MenuText, i+1, Skill_Names[i], Player_Skill[id][i], Skill_Max_Point[i], Skill_REQLevel[i] );
		}
		
		// The page is full
		if ( ( i + 1 ) == MAX_SKILLS_ONSIDE )
		{
			formatex ( MenuText, charsmax( MenuText ), "%s^n\w%d. Next Page^n", MenuText, i+1 ); 
			
			// One key for this menupoint
			KEY |= (1<<(i + 1));
			break;
		}
	}
	
	// We add the exit button
	formatex ( MenuText, charsmax( MenuText ), "%s^n\w0. Exit^n", MenuText );
	
	// One key for this menupoint
	KEY |= (1<<9)
	
	// Show the player the menu
	show_menu ( id, KEY, MenuText, 15, "SelectSkill" );
	
	return PLUGIN_CONTINUE;
}

public SetSkillMenu( id, key )
{
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// The player want the next side
	if ( key == 8 )
	{
		ChooseSkill( id, Player_SkillData[id][SKILL_SIDE]++ );
		
		return PLUGIN_CONTINUE;
	}
	
	// The player exit the menu
	else if ( key == 9 )
	{
		return PLUGIN_CONTINUE;
	}
		
	// We calculate the menu entry
	static MenuEntry;
	MenuEntry = ( Player_SkillData[id][SKILL_SIDE] * ( MAX_SKILLS_ONSIDE - 1 ) ) + key;
	
	// Set his new Skill +1
	Player_Skill[id][MenuEntry]++;
	
	// We remove one skillpoint because he set one
	Player_SkillData[id][AVAILABLE_SKILLS]--;
	
	// Is he now on the maximum?
	if ( Player_Skill[id][MenuEntry] == Skill_Max_Point[MenuEntry] )
	{
		client_print ( id, print_chat, "%s You are now a master of %s", SPARTA_NAME, Skill_Names[MenuEntry] );
	}
	
	// He isn't at the maximum
	else
	{
		// Show him a message an re-open the menu if he has more aviable skills to train
		client_print ( id, print_chat, "%s You skilled %s", SPARTA_NAME, Skill_Names[MenuEntry] );
	}
	
	// The player has more available skills, reopen the menu!
	if ( Player_SkillData[id][AVAILABLE_SKILLS] > 0 )
	{
		ChooseSkill( id, Player_SkillData[id][SKILL_SIDE] );
	}
	
	// Update his new skills
	Update_Skills( id );
	
	return PLUGIN_CONTINUE;
}

// Reset all the skills from the player and delete skillpoints 
public ResetAllSkills( id )
{
	// Allow the skills functions to set the skills to default
	g_AllowGivTakeSkill = true;
	
	// We loop through all skills and set they to zero
	static i;
	for ( i = 0; i < MAX_SKILLS; i++ )
	{
		Player_Skill[id][i] = 0;
	}
	
	// Update the skills
	if ( is_user_alive( id ) )
	{
		Update_Skills( id );
	}
	
	// We give him all skillpoints 
	Player_SkillData[id][AVAILABLE_SKILLS] = Player_Level[id];
	
	// send him an info mesage
	client_print( id, print_chat, "%s Your skills are reseted", SPARTA_NAME );
	
	return PLUGIN_CONTINUE;
}

// The player get on the server, maybe he forgot to skill now we calculate this!
public CheckAvailableSkills( id )
{
	static i, TempSkills; TempSkills = 0;
	for ( i = 0; i < MAX_SKILLS; ++i )
	{
		// We add all skillpoints to a var
		TempSkills += Player_Skill[id][i];
	}
	
	// Now we calculate the available skillpoints
	TempSkills = ( Player_Level[id] - TempSkills );
	
	// Get he skillpoints?
	if ( TempSkills > 0 )
	{
		Player_SkillData[id][AVAILABLE_SKILLS] += TempSkills;
	}
	
	// WTF he is in the negative!! :0
	else if ( TempSkills < 0 )
	{
		ResetAllSkills( id );
	}
}

// Update all skills for spawn
public Update_Skills( id )
{
	// Set the health from the player
	Skill_Health( id );
	
	// Set the gravity from the player
	Skill_Gravity( id );
	
	// Set the speed from the player
	if ( g_FreezeTimeOver )
	{
		Skill_SetSpeed( id + TASK_SPEED );
	}
	
	// Set the invisibility
	Skill_Invisible( id );
	
	// Okay, someone reseted the skills. Now we restrict this
	g_AllowGivTakeSkill = false;
}

// Checks if a player has skill all available skills
public bool:FullSkilled( id )
{
	// Loop through all skills and add the levels to a var
	new i, AllSkills = 0, AllSkillsPlayer = 0;
	for ( i = 0; i < MAX_SKILLS; ++i )
	{
		AllSkills += Skill_Max_Point[i];
		AllSkillsPlayer += Player_Skill[id][i];
	}
	
	// The player has skilled all skills
	if ( AllSkills == AllSkillsPlayer )
	{
		return true;
	}
	
	return false;
}
	
	
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
