// Global Ultimate

// The ultimate handler. Checks which ultimate the player has
public UltimateHandler( id )
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Dead players can't start their ultimates
	if ( !is_user_alive( id ) )
	{
		return PLUGIN_HANDLED;
	}
	
	// The ultimate delay isn't over
	if ( Player_UltDelay[id] > 0 )
	{
		UltErrorMessages( id, 1 );
		return PLUGIN_HANDLED;
	}
	
	// Freezetime is not over
	else if ( !g_FreezeTimeOver )
	{
		UltErrorMessages( id, 2 );
		return PLUGIN_HANDLED;
	}
	
	// The ultimate is running
	if ( task_exists( TASK_ULTIMATE + id ) )
	{
		UltErrorMessages( id, 4 );
		return PLUGIN_HANDLED;
	}
	
	// Player is silenced
	if ( Player_Silenced[id] )
	{
		UltErrorMessages( id, 6 );
		return PLUGIN_HANDLED;
	}
	
	switch ( Player_Ultimate[id] )
	{
		case ULTIMATE_NONE: // None 
		{
			UltErrorMessages( id, 5 );
		}
		
		case ULTIMATE_FLASH: // Air Flash
		{
			set_task ( 0.1, "AirFlash", ( TASK_ULTIMATE + id ) );
		}
		
		case ULTIMATE_BLAST: // Blast Wave
		{
			set_task ( 0.1, "BlastWave", ( TASK_ULTIMATE + id ) );
		}
		
		case ULTIMATE_NAPALM: // Napalm Attack
		{
			set_task ( 0.1, "NapalmAttack", ( TASK_ULTIMATE + id ) );
		}
		
		case ULTIMATE_LIGHTNING: // Chainlightning
		{
			set_task ( 0.1, "ActivLightning", ( TASK_ULTIMATE + id ) );
		}
	}
	
	return PLUGIN_HANDLED;
}

// This is called every second. It calculate the ultimates delay for the players
public CheckUlt()
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		// We need nomore the global counter
		if ( task_exists( TASK_GLOBALULT ) )
		{
			remove_task ( TASK_GLOBALULT );
		}
		
		return PLUGIN_CONTINUE;
	}
	
	static players[32], num, i;
	get_players ( players, num );
	
	for ( i = 0; i < num; ++i )
	{
		if ( !is_user_alive( players[i] ) )
		{
			continue;
		}
		
		// We're looking for ultimate owner's
		if ( Player_SkillData[players[i]][ISSEARCHING] == 1 )
		{
			// Play the ping sound
			emit_sound( players[i], CHAN_STATIC, g_Sound[ULTIMATESCAN_SOUND], 1.0, ATTN_NORM, 0, PITCH_NORM );
		}
		
		// the time is allready over
		if ( Player_UltDelay[players[i]] > 0 )
		{
			// lose one second
			Player_UltDelay[players[i]]--;
			
			// The ultimate is ready, give him this information
			if ( Player_UltDelay[players[i]] == 0 )
			{
				UltReady( players[i] );
			}
		}
	}
	
	return PLUGIN_CONTINUE;
}

// Send the player a message 
public UltErrorMessages( id, messagetyp )
{
	switch ( messagetyp )
	{
		case 1: // Ultimate not ready
		{
			static message[128];
			formatex ( message, charsmax( message ), "Ultimate not ready (%d sec)", Player_UltDelay[id] );
		
			// show a small message
			doTypesay ( message, 1, 255, 255, 255, 0, 2.0, id );
		}
		
		case 2: // Freezetime is not over
		{
			doTypesay ( "The Freezetime is not over!", 1, 255, 255, 255, 0, 2.0, id );
		}
		
		case 3: // Can't find enemys in range
		{
			doTypesay ( "Can't find enemys in range!", 1, 255, 255, 255, 0, 4.0, id );
		}
		
		case 4: // Ultimate is running
		{
			doTypesay ( "Ultimate is allready running!", 1, 255, 255, 255, 0, 4.0, id );
		}
		
		case 5: // None ultimate
		{
			doTypesay ( "You have currently no ultimate!", 1, 255, 255, 255, 0, 4.0, id );
		}
		
		case 6: // Player is silenced
		{
			doTypesay ( "You are currently silenced!", 1, 255, 255, 255, 0, 4.0, id );
		}
	}
}

public SelectUltimate( id )
{
	id -= TASK_SET_ULT;
	
	static MenuText[256];
	formatex ( MenuText, charsmax( MenuText ), "\yChose your Ultimate:\w^n^n" );
	
	static i, s_HowManyKeys; s_HowManyKeys = 0;
	for ( i = 1; i < MAX_ULTIMATES; ++i )
	{
		if ( Player_Level[id] >= Ultimate_REQLevel[i] )
		{
			// The player can chose an ultimate
			formatex ( MenuText, charsmax( MenuText ), "%s\w%d. %s (lvl %d)^n", MenuText, i, Ultimate_Names[i], Ultimate_REQLevel[i] );
			
			// we count it for the valid keys
			s_HowManyKeys++;
		}
		
		else
		{
			formatex ( MenuText, charsmax( MenuText ), "%s\d%d. %s (lvl %d)^n", MenuText, i, Ultimate_Names[i], Ultimate_REQLevel[i] );
		}
	}
	
	// We need the keys for the player
	static KEY;
	for ( i = 0; i < s_HowManyKeys; ++i )
	{
		KEY = KEY | (1<<i)
	}
	
	// Show the player the menu
	show_menu ( id, KEY, MenuText, 15, "SelectUlt" );
}

public SetUltimate( id, key )
{
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// This should never called
	if ( key < 0 || key > MAX_ULTIMATES )
	{
		client_print ( id, print_chat, "%s You choosed a wrong Ultimate. Try it again", SPARTA_NAME );
		set_task ( 2.0, "SelectUltimate", ( TASK_SET_ULT + id ) );
		
		return PLUGIN_CONTINUE;
	}
	
	// We have to add one to the key var
	key++;
	
	// Set his new Ultimate 
	Player_Ultimate[id] = key;
	
	// Update his new bar
	PlayerShowBar ( id );
	
	// Give him a message and save the xps + his new ultimate skill. 
	client_print ( id, print_chat, "%s You choosed %s. That was the right choice!", SPARTA_NAME, Ultimate_Names[key] );
	client_print ( id, print_chat, "%s Bind ^"f^" ^"ultimate^"", SPARTA_NAME );
	
	// Set the icon if the player is alive
	if ( is_user_alive( id ) )
	{
		HandleIcon( id, 1 );
	}
	
	if ( get_pcvar_num( sp_savexp ) )
	{
		SavePlayerXP( id );
	}
	
	return PLUGIN_CONTINUE;
}
	

public UltReady( id )
{
	// Send a message to the player (from wc3ft)
	set_hudmessage( 255, 208, 0, -1.0, 0.85, 0, 6.0, 0.5, 0.1, 0.5, 1 );
	show_hudmessage( id, "Ultimate is ready." );
	
	// Play a nice ready sound from wc3ft
	client_cmd ( id, "speak %s", g_Sound[ULTREADY_SOUND] );
	
	// the delay is not 0. So let us set it to 0 (not if csdm is enabled)
	if ( Player_UltDelay[id] > 0 && sp_csdm_active <= 0 )
	{
		Player_UltDelay[id] = 0;
	}
	
	// Handle the icon
	HandleIcon( id, 1 );
}

// Check if a player lose his ultimate
public CheckLoseUltimate( id )
{
	if ( Ultimate_REQLevel[Player_Ultimate[id]] > Player_Level[id] )
	{
		Player_Ultimate[id] = 0;
	}
	
	return PLUGIN_CONTINUE;
}

// Flash the icon
public FlashIcon( id, WhichUltimate )
{
	switch ( WhichUltimate )
	{
		case ULTIMATE_LIGHTNING: // Chainlightning
		{
			// Create the status icon
			Create_StatusIcon( id, 2, "dmg_shock", 255, 255, 255 );
		}
	}
	
	return PLUGIN_CONTINUE;
}

// Show the icon
public HandleIcon( id, flag )
{
	// The player spawned, well
	if ( flag == 1 )
	{
		// The ultimate has cooldown, can't display icon
		if ( Player_UltDelay[id] > 0 )
		{
			return PLUGIN_CONTINUE;
		}

		switch ( Player_Ultimate[id] )
		{
			case ULTIMATE_NAPALM: // Napalm Attack
			{
				// Create the status icon
				Create_StatusIcon( id, 1, "dmg_rad", 255, 0, 0 );
			}
			
			case ULTIMATE_FLASH: // Air Flash
			{
				// Create the status icon
				Create_StatusIcon( id, 1, "item_longjump", 0, 120, 120 );
			}
			
			case ULTIMATE_BLAST: // Blast Wave
			{
				// Create the status icon
				Create_StatusIcon( id, 1, "cross", 255, 0, 0 );
			}
				
			case ULTIMATE_LIGHTNING: // Chainlightning
			{
				// Create the status icon
				Create_StatusIcon( id, 1, "dmg_shock", 255, 255, 255 );
			}
		}
	}
	
	// The player died or the round is over
	else if ( flag == 0 )
	{
		switch ( Player_Ultimate[id] )
		{
			case ULTIMATE_NAPALM: // Napalm Attack
			{
				// Create the status icon
				Create_StatusIcon( id, 0, "dmg_rad", 0, 0, 0 );
			}
			
			case ULTIMATE_FLASH: // Air Flash
			{
				// Create the status icon
				Create_StatusIcon( id, 0, "item_longjump", 0, 0, 0 );
			}
			
			case ULTIMATE_BLAST: // Blast Wave
			{
				// Create the status icon
				Create_StatusIcon( id, 0, "cross", 0, 0, 0 );
			}
			
			case ULTIMATE_LIGHTNING: // Chainlightning
			{
				// Remove the status icon
				Create_StatusIcon( id, 0, "dmg_shock", 0, 0, 0 );
			}
		}
	}
	
	return PLUGIN_CONTINUE;
}
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
